@@ -100,7 +100,7 @@ class BertSTEMForTextClassification:
         text = df[col_text].values
         labels = df[col_labels].values
 
-        encoded_dict = self.tokenizer.batch_encode_plus(
+        encoded_dict = self._tokenizer.batch_encode_plus(
                                            list(text),                      # Sentence to encode.
                                            add_special_tokens = True, # Add '[CLS]' and '[SEP]'
                                            max_length = 120,
@@ -133,7 +133,7 @@ class BertSTEMForTextClassification:
         early_stopping = transformers.EarlyStoppingCallback(early_stopping_patience=5)
 
         trainer = transformers.Trainer(
-                               model=self.model,                         # the instantiated Transformers model to be trained
+                               model=self._model,                         # the instantiated Transformers model to be trained
                                args=training_args,                  # training arguments, defined above
                                train_dataset=dataset,               # training dataset
                                eval_dataset=dataset,                # evaluation dataset
